@@ -1,5 +1,3 @@
-#define NEED_eval_pv
-#include "ppport.h"
 #include <SDL.h>
 #include "SDL_thread.h"
 /* */
